@@ -104,7 +104,8 @@ def y_score_proba(model, X_test, y_test):
             y_score = None
             
     elif 'keras' in get.model_type(model):
-        prob = model.predict_proba(X_test)
+#       prob = model.predict_proba(X_test)   -- predict_proba() is deprecated.
+        prob = model.predict(X_test)
         if len(np.unique(y_test, axis = 0)) == 2 and prob.shape[1] == 1:
             y_score = np.c_[1-prob, prob]
             
@@ -170,5 +171,29 @@ def roc_pr_curve(model, X_test, y_test, *args):
     return(res_dict)
 
 # (DL & ML) & Regression
+def get_true_y(y_test):
+    
+    # reshape (dim2 -> dim1)
+    if len(y_test.shape) == 2:
+        true_y = y_test.reshape(1,-1)[0].tolist()
+    elif type(y_test) == list:
+        true_y = y_test
+    else:
+        true_y = y_test.tolist()
+    return(true_y)
+        
 def get_visual_info_regressor(model, X_test):
-    return(model.predict(X_test))
+    preds = model.predict(X_test)
+
+    # reshape (dim2 -> dim1)
+    if len(preds.shape) == 2:
+        preds = preds.reshape(1,-1)[0]
+
+    # 소수점 자리수 조정(소수점 이하 5번째 자리에서 반올림)
+    try:
+        if len(str(preds[0]).split('.')[1]) >= 5:
+            preds = np.round(preds, 4)
+            preds = list(map(float, np.array(preds, dtype = np.str).tolist()))
+    except TypeError:
+        pass
+    return(preds)
