@@ -2,6 +2,7 @@ from __future__ import print_function
 import os
 import sys
 import json
+import subprocess
 from Accuinsight.modeler.core.LcConst import LcConst
 
 _BASH_RC_PATH = '/home/notebook/.bashrc'
@@ -58,6 +59,10 @@ def __get_current_file(target_path, target_file):
     return current_notebook
 
 
+def __install_package(package_name):
+    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+
+
 def get_current_notebook():
     current_notebook = ''
     is_jupyter = is_in_ipython()
@@ -69,6 +74,7 @@ def get_current_notebook():
             current_notebook = __get_current_file(target_path=target_path, target_file=ret_file)
             current_notebook = current_notebook.split(':')[1]
         else:
+            __install_package('ipyparams')
             import ipyparams
             current_notebook = ipyparams.raw_url
             current_notebook = current_notebook.split('notebooks/')[1]
